from setuptools import setup

setup(
    name="RnDPackage",
    version="0.11",
    description="Shared packages for R&D projects",
    url="https://github.com/mehtarjt/python",
    author="RnD",
    author_email="mehtarjt@gmail.com",
    license="MIT",
    packages=["RnDPackage"],
    zip_safe=False,
    include_package_data=True,
)
